This is an automated email from the ASF dual-hosted git repository.
rrm pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/trafficserver.git
The following commit(s) were added to refs/heads/master by this push:
new affba2d Fixes spelling in iocore
affba2d is described below
commit affba2de28e1fad411e373b890b89ce4ca5dfd39
Author: Randall Meyer <[email protected]>
AuthorDate: Tue Aug 7 07:45:44 2018 -0700
Fixes spelling in iocore
---
iocore/aio/AIO.cc | 2 +-
iocore/cache/Cache.cc | 16 ++++++++--------
iocore/cache/CacheDir.cc | 4 ++--
iocore/cache/CacheHosting.cc | 8 ++++----
iocore/cache/CachePages.cc | 2 +-
iocore/cache/CacheRead.cc | 8 ++++----
iocore/cache/CacheWrite.cc | 6 +++---
iocore/cache/P_CacheDir.h | 2 +-
iocore/cache/P_CacheHosting.h | 2 +-
iocore/cache/P_CacheInternal.h | 4 ++--
iocore/cache/RamCacheCLFUS.cc | 4 ++--
iocore/cache/Store.cc | 8 ++++----
iocore/dns/DNS.cc | 4 ++--
iocore/dns/DNSConnection.cc | 2 +-
iocore/dns/test_P_DNS.cc | 2 +-
iocore/eventsystem/EventSystem.cc | 2 +-
iocore/eventsystem/I_Action.h | 10 +++++-----
iocore/eventsystem/I_Continuation.h | 2 +-
iocore/eventsystem/I_EThread.h | 24 ++++++++++++------------
iocore/eventsystem/I_Event.h | 6 +++---
iocore/eventsystem/I_EventProcessor.h | 8 ++++----
iocore/eventsystem/I_IOBuffer.h | 10 +++++-----
iocore/eventsystem/I_Lock.h | 4 ++--
iocore/eventsystem/I_Processor.h | 4 ++--
iocore/eventsystem/I_Thread.h | 2 +-
iocore/eventsystem/I_VConnection.h | 16 ++++++++--------
iocore/eventsystem/P_Freer.h | 2 +-
iocore/eventsystem/P_IOBuffer.h | 2 +-
iocore/eventsystem/Thread.cc | 2 +-
iocore/eventsystem/UnixEThread.cc | 2 +-
iocore/hostdb/HostDB.cc | 16 ++++++++--------
iocore/hostdb/I_HostDBProcessor.h | 8 ++++----
iocore/hostdb/P_RefCountCacheSerializer.h | 2 +-
iocore/hostdb/test_P_HostDB.cc | 2 +-
iocore/net/I_Net.h | 4 ++--
iocore/net/I_NetProcessor.h | 2 +-
iocore/net/I_NetVConnection.h | 18 +++++++++---------
iocore/net/I_UDPNet.h | 4 ++--
iocore/net/NetVCTest.cc | 4 ++--
iocore/net/OCSPStapling.cc | 2 +-
iocore/net/P_Connection.h | 4 ++--
iocore/net/P_NetVCTest.h | 2 +-
iocore/net/P_NetVConnection.h | 2 +-
iocore/net/P_SSLConfig.h | 2 +-
iocore/net/P_UDPNet.h | 2 +-
iocore/net/P_UnixNet.h | 4 ++--
iocore/net/P_UnixNetProcessor.h | 2 +-
iocore/net/P_UnixNetVConnection.h | 2 +-
iocore/net/SSLConfig.cc | 2 +-
iocore/net/SSLNetVConnection.cc | 8 ++++----
iocore/net/SSLNextProtocolSet.cc | 4 ++--
iocore/net/SSLSessionTicket.cc | 2 +-
iocore/net/SSLUtils.cc | 8 ++++----
iocore/net/Socks.cc | 6 +++---
iocore/net/UnixNet.cc | 2 +-
iocore/net/UnixNetVConnection.cc | 2 +-
iocore/net/YamlSNIConfig.cc | 2 +-
iocore/net/test_P_Net.cc | 2 +-
iocore/net/test_certlookup.cc | 2 +-
iocore/utils/I_OneWayMultiTunnel.h | 2 +-
iocore/utils/I_OneWayTunnel.h | 2 +-
61 files changed, 148 insertions(+), 148 deletions(-)
diff --git a/iocore/aio/AIO.cc b/iocore/aio/AIO.cc
index e908542..48e08b4 100644
--- a/iocore/aio/AIO.cc
+++ b/iocore/aio/AIO.cc
@@ -538,7 +538,7 @@ Lagain:
if (ret < 0) {
Debug("aio", "io_submit failed: %s (%d)", strerror(-ret), -ret);
} else {
- Fatal("could not sumbit IOs, io_submit(%p, %d, %p) returned %d", ctx,
num, cbs, ret);
+ Fatal("could not submit IOs, io_submit(%p, %d, %p) returned %d", ctx,
num, cbs, ret);
}
}
}
diff --git a/iocore/cache/Cache.cc b/iocore/cache/Cache.cc
index 8b6ab8d..d28fa4c 100644
--- a/iocore/cache/Cache.cc
+++ b/iocore/cache/Cache.cc
@@ -246,7 +246,7 @@ cache_stats_bytes_used_cb(const char *name, RecDataT
data_type, RecData *data, R
RecRawStatSyncSum(name, data_type, data, rsb, id);
RecGetGlobalRawStatSum(rsb, (int)cache_bytes_total_stat, &total);
percent_full = (float)used / (float)total * 100;
- // The perent_full float below gets rounded down
+ // The percent_full float below gets rounded down
RecSetGlobalRawStatSum(rsb, (int)cache_percent_full_stat,
(int64_t)percent_full);
}
@@ -851,7 +851,7 @@ CacheProcessor::cacheInitialized()
int caches_ready = 0;
int cache_init_ok = 0;
/* allocate ram size in proportion to the disk space the
- volume accupies */
+ volume occupies */
int64_t total_size = 0; // count in HTTP & MIXT
uint64_t total_cache_bytes = 0; // bytes that can used in total_size
uint64_t total_direntries = 0; // all the direntries in the cache
@@ -1138,7 +1138,7 @@ vol_init_data_internal(Vol *d)
off_t total_entries = (d->len - (d->start - d->skip)) /
cache_config_min_average_object_size;
// step2: calculate the number of buckets
off_t total_buckets = total_entries / DIR_DEPTH;
- // step3: calculate the number of segments, no semgent has more than 16384
buckets
+ // step3: calculate the number of segments, no segment has more than 16384
buckets
d->segments = (total_buckets + (((1 << 16) - 1) / DIR_DEPTH)) / ((1 << 16) /
DIR_DEPTH);
// step4: divide total_buckets into segments on average.
d->buckets = (total_buckets + d->segments - 1) / d->segments;
@@ -1531,7 +1531,7 @@ Vol::handle_recover_from_data(int event, void * /* data
ATS_UNUSED */)
s += round_to_approx_size(doc->len);
continue;
}
- // case 3 - we have already recoverd some data and
+ // case 3 - we have already recovered some data and
// (doc->sync_serial < last_sync_serial) ||
// (doc->sync_serial > header->sync_serial + 1).
// if we are too close to the end, wrap around
@@ -1855,7 +1855,7 @@ build_vol_hash_table(CacheHostRecord *cp)
for (int i = 0; i < VOL_HASH_TABLE_SIZE; i++) {
ttable[i] = VOL_HASH_EMPTY;
}
- // generate random numbers proportaion to allocation
+ // generate random numbers proportional to allocation
rtable_pair *rtable = (rtable_pair *)ats_malloc(sizeof(rtable_pair) *
rtable_size);
int rindex = 0;
for (int i = 0; i < num_vols; i++) {
@@ -2154,7 +2154,7 @@ unmarshal_helper(Doc *doc, Ptr<IOBufferData> &buf, int
&okay)
@internal I looked at doing this in place (rather than a copy & modify) but
- The in place logic would be even worse than this mess
- It wouldn't save you that much, since you end up doing inserts early in
the buffer.
- Without extreme care in the logic it could end up doing more copying
thatn
+ Without extreme care in the logic it could end up doing more copying than
the simpler copy & modify.
@internal This logic presumes the existence of some slack at the end of
the buffer, which
@@ -2221,7 +2221,7 @@ upgrade_doc_version(Ptr<IOBufferData> &buf)
}
Doc *n_doc = reinterpret_cast<Doc *>(buf->data()); // access as current
version.
// For now the base header size is the same. If that changes we'll need
to handle the v22/23 case here
- // as with the v21 and shift the content down to accomodate the bigger
header.
+ // as with the v21 and shift the content down to accommodate the bigger
header.
ink_assert(sizeof(*n_doc) == sizeof(*doc));
n_doc->doc_type = CACHE_FRAG_TYPE_HTTP; // We converted so adjust
doc_type.
@@ -2795,7 +2795,7 @@ cplist_reconfigure()
}
}
- /* change percentages in the config patitions to absolute value */
+ /* change percentages in the config partitions to absolute value */
off_t tot_space_in_blks = 0;
off_t blocks_per_vol = VOL_BLOCK_SIZE / STORE_BLOCK_SIZE;
/* sum up the total space available on all the disks.
diff --git a/iocore/cache/CacheDir.cc b/iocore/cache/CacheDir.cc
index 109538f..a7a1255 100644
--- a/iocore/cache/CacheDir.cc
+++ b/iocore/cache/CacheDir.cc
@@ -558,7 +558,7 @@ Lagain:
if (collision) {
if (collision == e) {
collision = nullptr;
- // increment collison stat
+ // increment collision stat
// Note: dir_probe could be called multiple times
// for the same document and so the collision stat
// may not accurately reflect the number of documents
@@ -973,7 +973,7 @@ sync_cache_dir_on_shutdown()
int r = pwrite(d->fd, d->agg_buffer, d->agg_buf_pos,
d->header->write_pos);
if (r != d->agg_buf_pos) {
- ink_assert(!"flusing agg buffer failed");
+ ink_assert(!"flushing agg buffer failed");
continue;
}
d->header->last_write_pos = d->header->write_pos;
diff --git a/iocore/cache/CacheHosting.cc b/iocore/cache/CacheHosting.cc
index a57d3bb..5a6a7ce 100644
--- a/iocore/cache/CacheHosting.cc
+++ b/iocore/cache/CacheHosting.cc
@@ -100,8 +100,8 @@ CacheHostMatcher::Match(const char *rdata, int rlen,
CacheHostResult *result)
CacheHostRecord *data_ptr;
bool r;
- // Check to see if there is any work to do before makeing
- // the stirng copy
+ // Check to see if there is any work to do before making
+ // the string copy
if (num_el <= 0) {
return;
}
@@ -776,7 +776,7 @@ ConfigVolumes::BuildListFromString(char *config_file_path,
char *file_buf)
return;
}
-/* Test the cache volumeing with different configurations */
+/* Test the cache volume with different configurations */
#define MEGS_128 (128 * 1024 * 1024)
#define ROUND_TO_VOL_SIZE(_x) (((_x) + (MEGS_128 - 1)) & ~(MEGS_128 - 1))
extern CacheDisk **gdisks;
@@ -866,7 +866,7 @@ create_config(RegressionTest *t, int num)
total_space += vol_blocks;
}
- // make sure we have atleast 1280 M bytes
+ // make sure we have at least 1280 M bytes
if (total_space<(10 << 27)>> STORE_BLOCK_SHIFT) {
rprintf(t, "Not enough space for 10 volume\n");
return 0;
diff --git a/iocore/cache/CachePages.cc b/iocore/cache/CachePages.cc
index 089cb59..33f62be 100644
--- a/iocore/cache/CachePages.cc
+++ b/iocore/cache/CachePages.cc
@@ -548,7 +548,7 @@ ShowCache::lookup_regex(int event, Event *e)
" form.elements[0].value += urllist[c]+
\"%%0D%%0A\";\n"
" }\n"
" if (form.elements[0].value == \"\"){\n"
- " alert(\"Please select atleast one url before
clicking delete\");\n"
+ " alert(\"Please select at least one url before
clicking delete\");\n"
" return true;\n"
"}\n"
" srcfile=\"./delete_url?url=\" +
form.elements[0].value;\n"
diff --git a/iocore/cache/CacheRead.cc b/iocore/cache/CacheRead.cc
index 9217946..085ffca 100644
--- a/iocore/cache/CacheRead.cc
+++ b/iocore/cache/CacheRead.cc
@@ -838,7 +838,7 @@ CacheVC::openReadStartEarliest(int /* event ATS_UNUSED */,
Event * /* e ATS_UNUS
// an object needs to be outside the aggregation window in order to be
// be evacuated as it is read
if (!dir_agg_valid(vol, &dir)) {
- // a directory entry which is nolonger valid may have been overwritten
+ // a directory entry which is no longer valid may have been overwritten
if (!dir_valid(vol, &dir)) {
last_collision = nullptr;
}
@@ -864,7 +864,7 @@ CacheVC::openReadStartEarliest(int /* event ATS_UNUSED */,
Event * /* e ATS_UNUS
last_collision = nullptr;
goto Lread;
}
- if (!(doc->key == key)) { // collisiion
+ if (!(doc->key == key)) { // collision
goto Lread;
}
// success
@@ -1041,7 +1041,7 @@ CacheVC::openReadStartHead(int event, Event *e)
// an object needs to be outside the aggregation window in order to be
// be evacuated as it is read
if (!dir_agg_valid(vol, &dir)) {
- // a directory entry which is nolonger valid may have been overwritten
+ // a directory entry which is no longer valid may have been overwritten
if (!dir_valid(vol, &dir)) {
last_collision = nullptr;
}
@@ -1085,7 +1085,7 @@ CacheVC::openReadStartHead(int event, Event *e)
if (buf) {
HTTPCacheAlt *alt = reinterpret_cast<HTTPCacheAlt *>(doc->hdr());
int32_t alt_length = 0;
- // count should be reasonable, as vector is initialized and unlikly
to be too corrupted
+ // count should be reasonable, as vector is initialized and unlikely
to be too corrupted
// by bad disk data - count should be the number of successfully
unmarshalled alts.
for (int32_t i = 0; i < vector.count(); ++i) {
CacheHTTPInfo *info = vector.get(i);
diff --git a/iocore/cache/CacheWrite.cc b/iocore/cache/CacheWrite.cc
index 48d16cb..55ec3eb 100644
--- a/iocore/cache/CacheWrite.cc
+++ b/iocore/cache/CacheWrite.cc
@@ -400,7 +400,7 @@ CacheVC::evacuateReadHead(int /* event ATS_UNUSED */, Event
* /* e ATS_UNUSED */
if (!io.ok()) {
goto Ldone;
}
- // a directory entry which is nolonger valid may have been overwritten
+ // a directory entry which is no longer valid may have been overwritten
if (!dir_valid(vol, &dir)) {
last_collision = nullptr;
goto Lcollision;
@@ -500,7 +500,7 @@ CacheVC::evacuateDocDone(int /* event ATS_UNUSED */, Event
* /* e ATS_UNUSED */)
dir_overwrite(&doc->key, vol, &dir, &overwrite_dir);
}
// if the tag in the overwrite_dir matches the first_key in the
- // document, then it has to be the vector. We gaurantee that
+ // document, then it has to be the vector. We guarantee that
// the first_key and the earliest_key will never collide (see
// Cache::open_write). Once we know its the vector, we can
// safely overwrite the first_key in the directory.
@@ -677,7 +677,7 @@ Vol::evacuateDocReadDone(int event, Event *e)
b->f.unused = 87;
}
// if the tag in the c->dir does match the first_key in the
- // document, then it has to be the earliest fragment. We gaurantee that
+ // document, then it has to be the earliest fragment. We guarantee that
// the first_key and the earliest_key will never collide (see
// Cache::open_write).
if (!dir_head(&b->dir) || !dir_compare_tag(&b->dir, &doc->first_key)) {
diff --git a/iocore/cache/P_CacheDir.h b/iocore/cache/P_CacheDir.h
index 576224f..58c1c9f 100644
--- a/iocore/cache/P_CacheDir.h
+++ b/iocore/cache/P_CacheDir.h
@@ -299,7 +299,7 @@ void sync_cache_dir_on_shutdown();
extern Dir empty_dir;
-// Inline Funtions
+// Inline Functions
#define dir_in_seg(_s, _i) ((Dir *)(((char *)(_s)) + (SIZEOF_DIR * (_i))))
diff --git a/iocore/cache/P_CacheHosting.h b/iocore/cache/P_CacheHosting.h
index 765c695..90822e2 100644
--- a/iocore/cache/P_CacheHosting.h
+++ b/iocore/cache/P_CacheHosting.h
@@ -98,7 +98,7 @@ private:
HostLookup *host_lookup; // Data structure to do the lookups
CacheHostRecord *data_array; // array of all data items
int array_len; // the length of the arrays
- int num_el; // the number of itmems in the tree
+ int num_el; // the number of items in the tree
CacheType type;
};
diff --git a/iocore/cache/P_CacheInternal.h b/iocore/cache/P_CacheInternal.h
index 7ba0e24..1a61b71 100644
--- a/iocore/cache/P_CacheInternal.h
+++ b/iocore/cache/P_CacheInternal.h
@@ -433,7 +433,7 @@ struct CacheVC : public CacheVConnection {
// Start Region C
// These variables are memset to 0 when the structure is freed.
// The size of this region is size_to_init which is initialized
- // in the CacheVC constuctor. It assumes that vio is the start
+ // in the CacheVC constructor. It assumes that vio is the start
// of this region.
// NOTE: NOTE: NOTE: If vio is NOT the start, then CHANGE the
// size_to_init initialization
@@ -578,7 +578,7 @@ free_CacheVC(CacheVC *cont)
ink_assert(!cont->is_io_in_progress());
ink_assert(!cont->od);
/* calling cont->io.action = nullptr causes compile problem on 2.6 solaris
- release build....wierd??? For now, null out continuation and mutex
+ release build....weird??? For now, null out continuation and mutex
of the action separately */
cont->io.action.continuation = nullptr;
cont->io.action.mutex = nullptr;
diff --git a/iocore/cache/RamCacheCLFUS.cc b/iocore/cache/RamCacheCLFUS.cc
index 3fe4af0..cca0ee1 100644
--- a/iocore/cache/RamCacheCLFUS.cc
+++ b/iocore/cache/RamCacheCLFUS.cc
@@ -35,7 +35,7 @@
#endif
#define REQUIRED_COMPRESSION 0.9 // must get to this size or declared
incompressible
-#define REQUIRED_SHRINK 0.8 // must get to this size or keep orignal
buffer (with padding)
+#define REQUIRED_SHRINK 0.8 // must get to this size or keep original
buffer (with padding)
#define HISTORY_HYSTERIA 10 // extra temporary history
#define ENTRY_OVERHEAD 256 // per-entry overhead to consider when
computing cache value/size
#define LZMA_BASE_MEMLIMIT (64 * 1024 * 1024)
@@ -53,7 +53,7 @@ struct RamCacheCLFUSEntry {
uint32_t auxkey1;
uint32_t auxkey2;
uint64_t hits;
- uint32_t size; // memory used including paddding in buffer
+ uint32_t size; // memory used including padding in buffer
uint32_t len; // actual data length
uint32_t compressed_len;
union {
diff --git a/iocore/cache/Store.cc b/iocore/cache/Store.cc
index 38deecd..778306a 100644
--- a/iocore/cache/Store.cc
+++ b/iocore/cache/Store.cc
@@ -46,7 +46,7 @@ make_span_error(int error)
switch (error) {
case ENOENT:
return SPAN_ERROR_NOT_FOUND;
- case EPERM: /* fallthru */
+ case EPERM: /* fallthrough */
case EACCES:
return SPAN_ERROR_NO_ACCESS;
default:
@@ -213,7 +213,7 @@ Span::errorstr(span_error_t serr)
return "unsupported cache file type";
case SPAN_ERROR_MEDIA_PROBE:
return "failed to probe device geometry";
- case SPAN_ERROR_UNKNOWN: /* fallthru */
+ case SPAN_ERROR_UNKNOWN: /* fallthrough */
default:
return "unknown error";
}
@@ -652,7 +652,7 @@ void
Store::spread_alloc(Store &s, unsigned int blocks, bool mmapable)
{
//
- // Count the eligable disks..
+ // Count the eligible disks..
//
int mmapable_disks = 0;
for (unsigned k = 0; k < n_disks; k++) {
@@ -738,7 +738,7 @@ Store::try_realloc(Store &s, Store &diff)
}
//
-// Stupid grab first availabled space allocator
+// Stupid grab first available space allocator
//
void
Store::alloc(Store &s, unsigned int blocks, bool one_only, bool mmapable)
diff --git a/iocore/dns/DNS.cc b/iocore/dns/DNS.cc
index 4117355..509ae29 100644
--- a/iocore/dns/DNS.cc
+++ b/iocore/dns/DNS.cc
@@ -577,7 +577,7 @@ DNSHandler::startEvent(int /* event ATS_UNUSED */, Event *e)
/**
Initial state of the DSNHandler. Can reinitialize the running DNS
- hander to a new nameserver.
+ handler to a new nameserver.
*/
int
DNSHandler::startEvent_sdns(int /* event ATS_UNUSED */, Event *e)
@@ -1192,7 +1192,7 @@ DNSEntry::mainEvent(int event, Event *e)
} else {
domains = nullptr;
}
- Debug("dns", "enqueing query %s", qname);
+ Debug("dns", "enqueuing query %s", qname);
DNSEntry *dup = get_entry(dnsH, qname, qtype);
if (dup) {
Debug("dns", "collapsing NS request");
diff --git a/iocore/dns/DNSConnection.cc b/iocore/dns/DNSConnection.cc
index fc4cb32..5a1408d 100644
--- a/iocore/dns/DNSConnection.cc
+++ b/iocore/dns/DNSConnection.cc
@@ -80,7 +80,7 @@ DNSConnection::trigger()
// Since the periodic check is removed, we need to call
// this when it's triggered by EVENTIO_DNS_CONNECTION.
- // The handler should be pionting to DNSHandler::mainEvent.
+ // The handler should be pointing to DNSHandler::mainEvent.
// We can schedule an immediate event or call the handler
// directly, and since both arguments are not being used
// passing in 0 and nullptr will do the job.
diff --git a/iocore/dns/test_P_DNS.cc b/iocore/dns/test_P_DNS.cc
index fecca6d..378fa94 100644
--- a/iocore/dns/test_P_DNS.cc
+++ b/iocore/dns/test_P_DNS.cc
@@ -55,7 +55,7 @@ struct NetTesterSM : public Continuation {
fflush(stdout);
break;
case VC_EVENT_READ_COMPLETE:
- /* FALLSTHROUGH */
+ /* FALLTHROUGH */
case VC_EVENT_EOS:
r = reader->read_avail();
str = new char[r + 10];
diff --git a/iocore/eventsystem/EventSystem.cc
b/iocore/eventsystem/EventSystem.cc
index c7f1e99..f5d5dc0 100644
--- a/iocore/eventsystem/EventSystem.cc
+++ b/iocore/eventsystem/EventSystem.cc
@@ -37,7 +37,7 @@ ink_event_system_init(ts::ModuleVersion v)
int config_max_iobuffer_size = DEFAULT_MAX_BUFFER_SIZE;
int iobuffer_advice = 0;
- // For backwards compatability make sure to allow thread_freelist_size
+ // For backwards compatibility make sure to allow thread_freelist_size
// This needs to change in 6.0
REC_EstablishStaticConfigInt32(thread_freelist_high_watermark,
"proxy.config.allocator.thread_freelist_size");
diff --git a/iocore/eventsystem/I_Action.h b/iocore/eventsystem/I_Action.h
index 444e211..edd9159 100644
--- a/iocore/eventsystem/I_Action.h
+++ b/iocore/eventsystem/I_Action.h
@@ -78,7 +78,7 @@
Allocation policy:
Actions are allocated by the Processor performing the actions.
- It is the processor's responsbility to handle deallocation once
+ It is the processor's responsibility to handle deallocation once
the action is complete or cancelled. A state machine MUST NOT
access an action once the operation that returned the Action has
completed or it has cancelled the Action.
@@ -88,11 +88,11 @@ class Action
{
public:
/**
- Contination that initiated this action.
+ Continuation that initiated this action.
The reference to the initiating continuation is only used to
verify that the action is being cancelled by the correct
- continuation. This field should not be accesed or modified
+ continuation. This field should not be accessed or modified
directly by the state machine.
*/
@@ -103,7 +103,7 @@ public:
Keeps a reference to the Continuation's lock to preserve the
access to the cancelled field valid even when the state machine
- has been deallocated. This field should not be accesed or
+ has been deallocated. This field should not be accessed or
modified directly by the state machine.
*/
@@ -114,7 +114,7 @@ public:
cancelled.
This flag is set after a call to cancel or cancel_action and
- it should not be accesed or modified directly by the state
+ it should not be accessed or modified directly by the state
machine.
*/
diff --git a/iocore/eventsystem/I_Continuation.h
b/iocore/eventsystem/I_Continuation.h
index a7cceb6..b4531a9 100644
--- a/iocore/eventsystem/I_Continuation.h
+++ b/iocore/eventsystem/I_Continuation.h
@@ -23,7 +23,7 @@
@section details Details
Continuations have a handleEvent() method to invoke them. Users
- can determine the behavior of a Continuation by suppling a
+ can determine the behavior of a Continuation by supplying a
"ContinuationHandler" (member function name) which is invoked
when events arrive. This function can be changed with the
"setHandler" method.
diff --git a/iocore/eventsystem/I_EThread.h b/iocore/eventsystem/I_EThread.h
index a0518fd..7e86c8e 100644
--- a/iocore/eventsystem/I_EThread.h
+++ b/iocore/eventsystem/I_EThread.h
@@ -56,7 +56,7 @@ enum ThreadType {
The EThread class is the type of thread created and managed by
the Event System. It is one of the available interfaces for
- schedulling events in the event system (another two are the Event
+ scheduling events in the event system (another two are the Event
and EventProcessor classes).
In order to handle events, each EThread object has two event
@@ -73,7 +73,7 @@ enum ThreadType {
Scheduling Interface:
- There are eight schedulling functions provided by EThread and
+ There are eight scheduling functions provided by EThread and
they are a wrapper around their counterparts in EventProcessor.
@see EventProcessor
@@ -121,7 +121,7 @@ public:
continuation's handler. See the the EventProcessor class.
@param cookie User-defined value or pointer to be passed back
in the Event's object cookie field.
- @return Reference to an Event object representing the schedulling
+ @return Reference to an Event object representing the scheduling
of this callback.
*/
@@ -143,7 +143,7 @@ public:
continuation's handler. See the EventProcessor class.
@param cookie User-defined value or pointer to be passed back
in the Event's object cookie field.
- @return A reference to an Event object representing the schedulling
+ @return A reference to an Event object representing the scheduling
of this callback.
*/
@@ -163,7 +163,7 @@ public:
continuation's handler. See the EventProcessor class.
@param cookie User-defined value or pointer to be passed back
in the Event's object cookie field.
- @return A reference to an Event object representing the schedulling
+ @return A reference to an Event object representing the scheduling
of this callback.
*/
@@ -177,14 +177,14 @@ public:
to occur every time 'aperiod' elapses. It is scheduled on this
EThread.
- @param c Continuation to call back everytime 'aperiod' elapses.
+ @param c Continuation to call back every time 'aperiod' elapses.
@param aperiod Duration of the time period between callbacks.
@param callback_event Event code to be passed back to the
continuation's handler. See the Remarks section in the
EventProcessor class.
@param cookie User-defined value or pointer to be passed back
in the Event's object cookie field.
- @return A reference to an Event object representing the schedulling
+ @return A reference to an Event object representing the scheduling
of this callback.
*/
@@ -202,7 +202,7 @@ public:
continuation's handler. See the EventProcessor class.
@param cookie User-defined value or pointer to be passed back
in the Event's object cookie field.
- @return A reference to an Event object representing the schedulling
+ @return A reference to an Event object representing the scheduling
of this callback.
*/
@@ -223,7 +223,7 @@ public:
continuation's handler. See the EventProcessor class.
@param cookie User-defined value or pointer to be passed back
in the Event's object cookie field.
- @return A reference to an Event object representing the schedulling
+ @return A reference to an Event object representing the scheduling
of this callback.
*/
@@ -244,7 +244,7 @@ public:
EventProcessor class.
@param cookie User-defined value or pointer to be passed back
in the Event's object cookie field.
- @return A reference to an Event object representing the schedulling
+ @return A reference to an Event object representing the scheduling
of this callback.
*/
@@ -257,14 +257,14 @@ public:
Schedules the callback to the continuation 'c' to occur every
time 'aperiod' elapses. It is scheduled on this EThread.
- @param c Continuation to call back everytime 'aperiod' elapses.
+ @param c Continuation to call back every time 'aperiod' elapses.
@param aperiod Duration of the time period between callbacks.
@param callback_event Event code to be passed back to the
continuation's handler. See the Remarks section in the
EventProcessor class.
@param cookie User-defined value or pointer to be passed back
in the Event's object cookie field.
- @return A reference to an Event object representing the schedulling
+ @return A reference to an Event object representing the scheduling
of this callback.
*/
diff --git a/iocore/eventsystem/I_Event.h b/iocore/eventsystem/I_Event.h
index 3f708db..e598add 100644
--- a/iocore/eventsystem/I_Event.h
+++ b/iocore/eventsystem/I_Event.h
@@ -166,7 +166,7 @@ public:
Instructs the event object to reschedule itself at the time
specified in atimeout_at on the EventProcessor.
- @param atimeout_at Time at which to callcallback. See the Remarks section.
+ @param atimeout_at Time at which to call the callback. See the Remarks
section.
@param callback_event Event code to return at the completion of this
event. See the Remarks section.
*/
@@ -177,7 +177,7 @@ public:
Instructs the event object to reschedule itself at the time
specified in atimeout_at on the EventProcessor.
- @param atimeout_in Time at which to callcallback. See the Remarks section.
+ @param atimeout_in Time at which to call the callback. See the Remarks
section.
@param callback_event Event code to return at the completion of this
event. See the Remarks section.
*/
@@ -188,7 +188,7 @@ public:
the event object to reschedule itself to callback every 'aperiod'
from now.
- @param aperiod Time period at which to callcallback. See the Remarks
section.
+ @param aperiod Time period at which to call the callback. See the Remarks
section.
@param callback_event Event code to return at the completion of this
event. See the Remarks section.
*/
diff --git a/iocore/eventsystem/I_EventProcessor.h
b/iocore/eventsystem/I_EventProcessor.h
index 2bf9010..031ca71 100644
--- a/iocore/eventsystem/I_EventProcessor.h
+++ b/iocore/eventsystem/I_EventProcessor.h
@@ -73,8 +73,8 @@ class EThread;
thread is independent of the thread groups and it exists as long as your
continuation handle
executes and there are events to process. In the latter, you call @c
registerEventType to get an
event type and then @c spawn_event_theads which creates the threads in the
group of that
- type. Such threads require events to be scheduled on a specicif thread in
the group or for the
- grouop in general using the event type. Note that between these two calls @c
+ type. Such threads require events to be scheduled on a specific thread in
the group or for the
+ group in general using the event type. Note that between these two calls @c
EThread::schedule_spawn can be used to set up per thread initialization.
Callback event codes:
@@ -204,11 +204,11 @@ public:
/**
Schedules the continuation on a specific thread group to receive
an event periodically. Requests the EventProcessor to schedule the
- callback to the continuation 'c' everytime 'aperiod' elapses. The
+ callback to the continuation 'c' every time 'aperiod' elapses. The
callback is handled by a thread in the specified thread group
(event_type).
- @param c Continuation to call back everytime 'aperiod' elapses.
+ @param c Continuation to call back every time 'aperiod' elapses.
@param aperiod duration of the time period between callbacks.
@param event_type thread group id (or event type) specifying the
group of threads on which to schedule the callback.
diff --git a/iocore/eventsystem/I_IOBuffer.h b/iocore/eventsystem/I_IOBuffer.h
index 88a54cf..90b599a 100644
--- a/iocore/eventsystem/I_IOBuffer.h
+++ b/iocore/eventsystem/I_IOBuffer.h
@@ -29,7 +29,7 @@
might wish to ensure that an entire line will come in before consuming
the data. In such a case, the water_mark should be set to the largest
possible size of the string. (appropriate error handling should take
- care of exessively long strings).
+ care of excessively long strings).
In all other cases, especially when all data will be consumed, the
water_mark should be set to 0 (the default).
@@ -418,7 +418,7 @@ public:
Create a copy of the IOBufferBlock. Creates and returns a copy of this
IOBufferBlock that references the same data that this IOBufferBlock
(it does not allocate an another buffer). The cloned block will not
- have a writable space since the original IOBufferBlock mantains the
+ have a writable space since the original IOBufferBlock maintains the
ownership for writing data to the block.
@return copy of this IOBufferBlock.
@@ -715,7 +715,7 @@ public:
/**
Clears all fields in this IOBuffeReader, rendering it unusable. Drops
- the reference to the IOBufferBlock list, the accesor, MIOBuffer and
+ the reference to the IOBufferBlock list, the accessor, MIOBuffer and
resets this reader's state. You have to set those fields in order
to use this object again.
@@ -820,7 +820,7 @@ public:
@param offset number of the bytes to skip over before beginning
the operation.
@return -1 if c is not found, otherwise position of the first
- ocurrence.
+ occurrence.
*/
inkcoreapi int64_t memchr(char c, int64_t len = INT64_MAX, int64_t offset =
0);
@@ -1082,7 +1082,7 @@ public:
/**
Returns the amount of space of available for writing on the first
- writable block on the block chain (the one that would be reutrned
+ writable block on the block chain (the one that would be returned
by first_write_block()).
*/
diff --git a/iocore/eventsystem/I_Lock.h b/iocore/eventsystem/I_Lock.h
index 0017725..c061d26 100644
--- a/iocore/eventsystem/I_Lock.h
+++ b/iocore/eventsystem/I_Lock.h
@@ -129,7 +129,7 @@ inkcoreapi extern void lock_taken(const SourceLocation &,
const char *handler);
A ProxyMutex object has an ink_mutex member (defined in ink_mutex.h)
which is a wrapper around the platform dependent mutex type. This
- member allows the ProxyMutex to provide the functionallity required
+ member allows the ProxyMutex to provide the functionality required
by the users of the class without the burden of platform specific
function calls.
@@ -234,7 +234,7 @@ public:
}
};
-// The ClassAlocator for ProxyMutexes
+// The ClassAllocator for ProxyMutexes
extern inkcoreapi ClassAllocator<ProxyMutex> mutexAllocator;
inline bool
diff --git a/iocore/eventsystem/I_Processor.h b/iocore/eventsystem/I_Processor.h
index cce9a01..291c738 100644
--- a/iocore/eventsystem/I_Processor.h
+++ b/iocore/eventsystem/I_Processor.h
@@ -41,7 +41,7 @@ class Thread;
processors in the IO Core. A processor is multithreaded subsystem
specialized in some type of task or application. For example,
the Event System module includes the EventProcessor which provides
- schedulling services, the Net module includes the NetProcessor
+ scheduling services, the Net module includes the NetProcessor
which provides networking services, etc.
You cannot create objects of the Processor class and its methods
@@ -76,7 +76,7 @@ public:
virtual int get_thread_count();
/**
- This function attemps to stop the processor. Please refer to
+ This function attempts to stop the processor. Please refer to
the documentation on each processor to determine if it is
supported.
diff --git a/iocore/eventsystem/I_Thread.h b/iocore/eventsystem/I_Thread.h
index e2c46b3..54cb9b0 100644
--- a/iocore/eventsystem/I_Thread.h
+++ b/iocore/eventsystem/I_Thread.h
@@ -147,7 +147,7 @@ public:
This gets a cached copy of the time so it is very fast and reasonably
accurate.
The cached time is updated every time the actual operating system time
is fetched which is
at least every 10ms and generally more frequently.
- @note The cached copy shared among threads which means the cached copy
is udpated
+ @note The cached copy shared among threads which means the cached copy
is updated
for all threads if any thread updates it.
*/
static ink_hrtime get_hrtime();
diff --git a/iocore/eventsystem/P_Freer.h b/iocore/eventsystem/P_Freer.h
index c620c57..374af33 100644
--- a/iocore/eventsystem/P_Freer.h
+++ b/iocore/eventsystem/P_Freer.h
@@ -27,7 +27,7 @@
#include "I_Tasks.h"
// Note that these should not be used for memory that wishes to retain
-// NUMA socket affinity. We'll potentially return these on an arbitarily
+// NUMA socket affinity. We'll potentially return these on an arbitrarily
// selected processor/socket.
template <class C> struct DeleterContinuation : public Continuation {
diff --git a/iocore/eventsystem/P_IOBuffer.h b/iocore/eventsystem/P_IOBuffer.h
index 4968ff9..c13202d 100644
--- a/iocore/eventsystem/P_IOBuffer.h
+++ b/iocore/eventsystem/P_IOBuffer.h
@@ -709,7 +709,7 @@ TS_INLINE char &IOBufferReader::operator[](int64_t i)
}
ink_release_assert(!"out of range");
- // Never used, just to satisfy compilers not undersatnding the fatality of
ink_release_assert().
+ // Never used, just to satisfy compilers not understanding the fatality of
ink_release_assert().
return default_ret;
}
diff --git a/iocore/eventsystem/Thread.cc b/iocore/eventsystem/Thread.cc
index e239bf3..90faf9d 100644
--- a/iocore/eventsystem/Thread.cc
+++ b/iocore/eventsystem/Thread.cc
@@ -73,7 +73,7 @@ Thread::~Thread()
///////////////////////////////////////////////
struct thread_data_internal {
- ThreadFunction f; ///< Function to excecute in the thread.
+ ThreadFunction f; ///< Function to execute in the thread.
Thread *me; ///< The class instance.
char name[MAX_THREAD_NAME_LENGTH]; ///< Name for the thread.
};
diff --git a/iocore/eventsystem/UnixEThread.cc
b/iocore/eventsystem/UnixEThread.cc
index d0f896d..a579322 100644
--- a/iocore/eventsystem/UnixEThread.cc
+++ b/iocore/eventsystem/UnixEThread.cc
@@ -128,7 +128,7 @@ EThread::process_event(Event *e, int calling_code)
return;
}
Continuation *c_temp = e->continuation;
- // Make sure that the contination is locked before calling the handler
+ // Make sure that the continuation is locked before calling the handler
e->continuation->handleEvent(calling_code, e);
ink_assert(!e->in_the_priority_queue);
ink_assert(c_temp == e->continuation);
diff --git a/iocore/hostdb/HostDB.cc b/iocore/hostdb/HostDB.cc
index 9f4110a..179a040 100644
--- a/iocore/hostdb/HostDB.cc
+++ b/iocore/hostdb/HostDB.cc
@@ -392,7 +392,7 @@ HostDBProcessor::start(int, size_t)
statPagesManager.register_http("hostdb", register_ShowHostDB);
//
- // Register configuration callback, and establish configuation links
+ // Register configuration callback, and establish configuration links
//
REC_EstablishStaticConfigInt32(hostdb_ttl_mode,
"proxy.config.hostdb.ttl_mode");
REC_EstablishStaticConfigInt32(hostdb_disable_reverse_lookup,
"proxy.config.cache.hostdb.disable_reverse_lookup");
@@ -897,7 +897,7 @@ HostDBProcessor::setby(const char *hostname, int len,
sockaddr const *ip, HostDB
}
return;
}
- // Create a continuation to do a deaper probe in the background
+ // Create a continuation to do a deeper probe in the background
HostDBContinuation *c = hostDBContAllocator.alloc();
c->init(hash);
@@ -920,7 +920,7 @@ HostDBProcessor::setby_srv(const char *hostname, int len,
const char *target, Ho
hash.db_mark = HOSTDB_MARK_SRV;
hash.refresh();
- // Create a continuation to do a deaper probe in the background
+ // Create a continuation to do a deeper probe in the background
HostDBContinuation *c = hostDBContAllocator.alloc();
c->init(hash);
@@ -1414,7 +1414,7 @@ HostDBContinuation::dnsEvent(int event, HostEnt *e)
}
// We have seen cases were the action.mutex != action.continuation.mutex.
- // Since reply_to_cont will call the hanlder on the action.continuation,
it is important that we hold
+ // Since reply_to_cont will call the handler on the action.continuation,
it is important that we hold
// that mutex.
bool need_to_reschedule = true;
MUTEX_TRY_LOCK(lock, action.mutex, thread);
@@ -1559,7 +1559,7 @@ HostDBContinuation::probeEvent(int /* event ATS_UNUSED
*/, Event *e)
reply_to_cont(action.continuation, r.get());
}
- // If it suceeds or it was a remote probe, we are done
+ // If it succeeds or it was a remote probe, we are done
//
if (r) {
hostdb_cont_free(this);
@@ -1830,7 +1830,7 @@ struct ShowHostDB : public ShowCont {
if (event == EVENT_INTERVAL) {
HostDBInfo *r = reinterpret_cast<HostDBInfo *>(e);
if (output_json && records_seen++ > 0) {
- CHECK_SHOW(show(",")); // we need to seperate records
+ CHECK_SHOW(show(",")); // we need to separate records
}
showOne(r, false, event, e);
if (r->round_robin) {
@@ -1852,7 +1852,7 @@ struct ShowHostDB : public ShowCont {
for (int i = 0; i < rr_data->rrcount; i++) {
showOne(&rr_data->info(i), true, event, e, rr_data);
if (output_json) {
- CHECK_SHOW(show("}")); // we need to seperate records
+ CHECK_SHOW(show("}")); // we need to separate records
if (i < (rr_data->rrcount - 1))
CHECK_SHOW(show(","));
}
@@ -2333,7 +2333,7 @@ struct HostDBRegressionContinuation : public Continuation
{
hostDBProcessor.getbyname_re(this, hostnames[i++], 0);
return EVENT_CONT;
} else {
- rprintf(test, "HostDBTestRR: %d outstanding %d succcess %d failure\n",
outstanding, success, failure);
+ rprintf(test, "HostDBTestRR: %d outstanding %d success %d failure\n",
outstanding, success, failure);
if (success == hosts) {
*status = REGRESSION_TEST_PASSED;
} else {
diff --git a/iocore/hostdb/I_HostDBProcessor.h
b/iocore/hostdb/I_HostDBProcessor.h
index 2587131..3d15faf 100644
--- a/iocore/hostdb/I_HostDBProcessor.h
+++ b/iocore/hostdb/I_HostDBProcessor.h
@@ -51,7 +51,7 @@ struct HostDBContinuation;
// IP address.
//
// Since host information is relatively small, we can afford to have
-// a reasonable size memory cache, and use a (relatively) sparce
+// a reasonable size memory cache, and use a (relatively) sparse
// disk representation to decrease # of seeks.
//
extern int hostdb_enable;
@@ -84,7 +84,7 @@ makeHostHash(const char *string)
//
// This structure contains the host information required by
// the application. Except for the initial fields it
-// is treated as opacque by the database.
+// is treated as opaque by the database.
//
union HostDBApplicationInfo {
@@ -395,13 +395,13 @@ struct HostDBRoundRobin {
struct HostDBCache;
struct HostDBHash;
-// Prototype for inline completion functionf or
+// Prototype for inline completion function or
// getbyname_imm()
typedef void (Continuation::*cb_process_result_pfn)(HostDBInfo *r);
Action *iterate(Continuation *cont);
-/** The Host Databse access interface. */
+/** The Host Database access interface. */
struct HostDBProcessor : public Processor {
friend struct HostDBSync;
// Public Interface
diff --git a/iocore/hostdb/P_RefCountCacheSerializer.h
b/iocore/hostdb/P_RefCountCacheSerializer.h
index 41b80b5..e76b751 100644
--- a/iocore/hostdb/P_RefCountCacheSerializer.h
+++ b/iocore/hostdb/P_RefCountCacheSerializer.h
@@ -292,7 +292,7 @@ RefCountCacheSerializer<C>::finalize_sync()
return error;
}
- // Don't bother checking for errors on the close since theere's nothing we
can do about it at
+ // Don't bother checking for errors on the close since there's nothing we
can do about it at
// this point anyway.
socketManager.close(dirfd);
socketManager.close(this->fd);
diff --git a/iocore/hostdb/test_P_HostDB.cc b/iocore/hostdb/test_P_HostDB.cc
index 2768b43..7609c86 100644
--- a/iocore/hostdb/test_P_HostDB.cc
+++ b/iocore/hostdb/test_P_HostDB.cc
@@ -56,7 +56,7 @@ struct NetTesterSM : public Continuation {
fflush(stdout);
break;
case VC_EVENT_READ_COMPLETE:
- /* FALLSTHROUGH */
+ /* FALLTHROUGH */
case VC_EVENT_EOS:
r = reader->read_avail();
str = new char[r + 10];
diff --git a/iocore/net/I_Net.h b/iocore/net/I_Net.h
index 81ed6c3..050777c 100644
--- a/iocore/net/I_Net.h
+++ b/iocore/net/I_Net.h
@@ -22,9 +22,9 @@
@section details Details
- Net subsystem is a layer on top the operations sytem network apis. It
+ Net subsystem is a layer on top the operations system network apis. It
provides an interface for accepting/creating new connection oriented
- (TCP) and connection less (UDP) connetions and for reading/writing
+ (TCP) and connection less (UDP) connections and for reading/writing
data through these. The net system can manage 1000s of connections
very efficiently. Another advantage of using the net system is that
the SMs dont have be concerned about differences in the net apis of
diff --git a/iocore/net/I_NetProcessor.h b/iocore/net/I_NetProcessor.h
index 570e7f3..5f94cd6 100644
--- a/iocore/net/I_NetProcessor.h
+++ b/iocore/net/I_NetProcessor.h
@@ -240,7 +240,7 @@ private:
object.
@code
- netProcesors.accept(my_cont, ...);
+ netProcessor.accept(my_cont, ...);
netProcessor.connect_re(my_cont, ...);
@endcode
diff --git a/iocore/net/I_NetVConnection.h b/iocore/net/I_NetVConnection.h
index e1e9504..6f40159 100644
--- a/iocore/net/I_NetVConnection.h
+++ b/iocore/net/I_NetVConnection.h
@@ -258,13 +258,13 @@ struct NetVCOptions {
if (&that != this) {
/*
* It is odd but necessary to null the scoped string pointer here
- * and then explicitly call release on them in the string assignements
+ * and then explicitly call release on them in the string assignments
* below.
* We a memcpy from that to this. This will put that's string pointers
into
* this's memory. Therefore we must first explicitly null out
* this's original version of the string. The release after the
* memcpy removes the extra reference to that's copy of the string
- * Removing the release will eventualy cause a double free crash
+ * Removing the release will eventually cause a double free crash
*/
sni_servername = nullptr; // release any current name.
ssl_servername = nullptr;
@@ -358,7 +358,7 @@ public:
</tr>
<tr>
<td>c->handleEvent(VC_EVENT_ERROR, vio)</td>
- <td>signified that error occured during write.</td>
+ <td>signified that error occurred during write.</td>
</tr>
</table>
@@ -368,7 +368,7 @@ public:
when it is destroyed.
@param c continuation to be called back after (partial) write
- @param nbytes no of bytes to write, if unknown msut be set to INT64_MAX
+ @param nbytes no of bytes to write, if unknown must be set to INT64_MAX
@param buf source of data
@param owner
@return vio pointer
@@ -378,11 +378,11 @@ public:
/**
Closes the vconnection. A state machine MUST call do_io_close()
- when it has finished with a VConenction. do_io_close() indicates
+ when it has finished with a VConnection. do_io_close() indicates
that the VConnection can be deallocated. After a close has been
called, the VConnection and underlying processor must NOT send
any more events related to this VConnection to the state machine.
- Likeswise, state machine must not access the VConnectuion or
+ Likewise, state machine must not access the VConnection or
any returned VIOs after calling close. lerrno indicates whether
a close is a normal close or an abort. The difference between
a normal close and an abort depends on the underlying type of
@@ -401,7 +401,7 @@ public:
IO_SHUTDOWN_READWRITE. Once a side of a VConnection is shutdown,
no further I/O can be done on that side of the connections and
the underlying processor MUST NOT send any further events
- (INCLUDING TIMOUT EVENTS) to the state machine. The state machine
+ (INCLUDING TIMEOUT EVENTS) to the state machine. The state machine
MUST NOT use any VIOs from a shutdown side of a connection.
Even if both sides of a connection are shutdown, the state
machine MUST still call do_io_close() when it wishes the
@@ -438,7 +438,7 @@ public:
////////////////////////////////////////////////////////////
// Set the timeouts associated with this connection. //
- // active_timeout is for the total elasped time of //
+ // active_timeout is for the total elapsed time of //
// the connection. //
// inactivity_timeout is the elapsed time from the time //
// a read or a write was scheduled during which the //
@@ -461,7 +461,7 @@ public:
that it does not keep any connections open for a really long
time.
- Timeout symantics:
+ Timeout semantics:
Should a timeout occur, the state machine for the read side of
the NetVConnection is signaled first assuming that a read has
diff --git a/iocore/net/I_UDPNet.h b/iocore/net/I_UDPNet.h
index 9e4667d..846c3a7 100644
--- a/iocore/net/I_UDPNet.h
+++ b/iocore/net/I_UDPNet.h
@@ -46,7 +46,7 @@ class UDPNetProcessor : public Processor
public:
int start(int n_upd_threads, size_t stacksize) override = 0;
- // this function was interanal intially.. this is required for public and
+ // this function was internal initially.. this is required for public and
// interface probably should change.
bool CreateUDPSocket(int *resfd, sockaddr const *remote_addr, Action
**status, NetVCOptions &opt);
@@ -69,7 +69,7 @@ public:
@param recv_bufsize (optional) Socket buffer size for sending.
Limits how much can be queued by OS before we read it.
@return Action* Always returns ACTION_RESULT_DONE if socket was
- created successfuly, or ACTION_IO_ERROR if not.
+ created successfully, or ACTION_IO_ERROR if not.
*/
inkcoreapi Action *UDPBind(Continuation *c, sockaddr const *addr, int
send_bufsize = 0, int recv_bufsize = 0);
diff --git a/iocore/net/NetVCTest.cc b/iocore/net/NetVCTest.cc
index bda22bd..41ac801 100644
--- a/iocore/net/NetVCTest.cc
+++ b/iocore/net/NetVCTest.cc
@@ -26,7 +26,7 @@
NetVCTest.cc
Description:
- Unit test for infastructure for VConnections implementing the
+ Unit test for infrastructure for VConnections implementing the
NetVConnection interface
@@ -67,7 +67,7 @@ NVC_test_def netvc_tests_def[] = {
{"itimeout", 6000, 8000, 10, 10, 512, 10, VC_EVENT_READ_COMPLETE,
VC_EVENT_INACTIVITY_TIMEOUT},
{"itimeout", 10, 10, 6000, 8000, 512, 20, VC_EVENT_EOS,
VC_EVENT_WRITE_COMPLETE},
- // Test the small transfer code one byts at a time
+ // Test the small transfer code one byte at a time
{"smallt", 400, 400, 500, 500, 1, 15, VC_EVENT_READ_COMPLETE,
VC_EVENT_WRITE_COMPLETE},
{"smallt", 500, 500, 400, 400, 1, 15, VC_EVENT_READ_COMPLETE,
VC_EVENT_WRITE_COMPLETE},
diff --git a/iocore/net/OCSPStapling.cc b/iocore/net/OCSPStapling.cc
index 2ebae67..5a3121e 100644
--- a/iocore/net/OCSPStapling.cc
+++ b/iocore/net/OCSPStapling.cc
@@ -29,7 +29,7 @@
#include "P_SSLUtils.h"
#include "SSLStats.h"
-// Maxiumum OCSP stapling response size.
+// Maximum OCSP stapling response size.
// This should be the response for a single certificate and will typically
include the responder certificate chain,
// so 10K should be more than enough.
#define MAX_STAPLING_DER 10240
diff --git a/iocore/net/P_Connection.h b/iocore/net/P_Connection.h
index 9741fd7..8c8d4ce 100644
--- a/iocore/net/P_Connection.h
+++ b/iocore/net/P_Connection.h
@@ -42,7 +42,7 @@
The accept call is a blocking call while connect is non-blocking. They
returns a new Connection instance which is an handle to the newly created
connection. The connection `q instance can be used later for read/writes
- using an intance of IOProcessor class.
+ using an instance of IOProcessor class.
**************************************************************************/
@@ -143,7 +143,7 @@ struct Connection {
private:
// Don't want copy constructors to avoid having the deconstructor on
- // temporarly copies close the file descriptor too soon. Use move instead
+ // temporarily copies close the file descriptor too soon. Use move instead
Connection(Connection const &);
protected:
diff --git a/iocore/net/P_NetVCTest.h b/iocore/net/P_NetVCTest.h
index eedbb8d..f981932 100644
--- a/iocore/net/P_NetVCTest.h
+++ b/iocore/net/P_NetVCTest.h
@@ -26,7 +26,7 @@
P_NetVCTest.h
Description:
- Unit test for infastructure for VConnections implementing the
+ Unit test for infrastructure for VConnections implementing the
NetVConnection interface
diff --git a/iocore/net/P_NetVConnection.h b/iocore/net/P_NetVConnection.h
index 3d85e7a..679cf0b 100644
--- a/iocore/net/P_NetVConnection.h
+++ b/iocore/net/P_NetVConnection.h
@@ -40,7 +40,7 @@ NetVConnection::get_remote_addr()
inline IpEndpoint const &
NetVConnection::get_remote_endpoint()
{
- get_remote_addr(); // Make sure the vallue is filled in
+ get_remote_addr(); // Make sure the value is filled in
return remote_addr;
}
diff --git a/iocore/net/P_SSLConfig.h b/iocore/net/P_SSLConfig.h
index c0dc504..87a4a33 100644
--- a/iocore/net/P_SSLConfig.h
+++ b/iocore/net/P_SSLConfig.h
@@ -46,7 +46,7 @@ struct ssl_ticket_key_block;
//
// struct SSLConfigParams
//
-// configuration parameters as they apear in the global
+// configuration parameters as they appear in the global
// configuration file.
/////////////////////////////////////////////////////////////
diff --git a/iocore/net/P_UDPNet.h b/iocore/net/P_UDPNet.h
index 1be6d86..be2d896 100644
--- a/iocore/net/P_UDPNet.h
+++ b/iocore/net/P_UDPNet.h
@@ -193,7 +193,7 @@ public:
UDPPacketInternal *p;
// pull in all the stuff from long-term slot
lastPullLongTermQ = t;
- // this is to handle wierdoness where someone is trying to queue a
+ // this is to handle weirdness where someone is trying to queue a
// packet to be sent in SLOT_TIME_MSEC * N_SLOTS * (2+)---the packet
// will get back to longTermQ and we'll have an infinite loop.
while ((p = longTermQ.dequeue()) != nullptr)
diff --git a/iocore/net/P_UnixNet.h b/iocore/net/P_UnixNet.h
index 0440b72..7d591b0 100644
--- a/iocore/net/P_UnixNet.h
+++ b/iocore/net/P_UnixNet.h
@@ -343,7 +343,7 @@ public:
/**
Release a netvc and free it.
- @param netvc UnixNetVConnection to be deattached.
+ @param netvc UnixNetVConnection to be detached.
*/
void free_netvc(UnixNetVConnection *netvc);
@@ -353,7 +353,7 @@ private:
void _close_vc(UnixNetVConnection *vc, ink_hrtime now, int &handle_event,
int &closed, int &total_idle_time,
int &total_idle_count);
- /// Static method used as the callbackf for runtime configuration updates.
+ /// Static method used as the callback for runtime configuration updates.
static int update_nethandler_config(const char *name, RecDataT, RecData
data, void *);
};
diff --git a/iocore/net/P_UnixNetProcessor.h b/iocore/net/P_UnixNetProcessor.h
index b076c0a..5c19df4 100644
--- a/iocore/net/P_UnixNetProcessor.h
+++ b/iocore/net/P_UnixNetProcessor.h
@@ -66,7 +66,7 @@ extern UnixNetProcessor unix_netProcessor;
//
// Set up a thread to receive events from the NetProcessor
// This function should be called for all threads created to
-// accept such events by the EventProcesor.
+// accept such events by the EventProcessor.
//
extern void initialize_thread_for_net(EThread *thread);
diff --git a/iocore/net/P_UnixNetVConnection.h
b/iocore/net/P_UnixNetVConnection.h
index 46111bc..e4e0483 100644
--- a/iocore/net/P_UnixNetVConnection.h
+++ b/iocore/net/P_UnixNetVConnection.h
@@ -142,7 +142,7 @@ public:
////////////////////////////////////////////////////////////
// Set the timeouts associated with this connection. //
- // active_timeout is for the total elasped time of //
+ // active_timeout is for the total elapsed time of //
// the connection. //
// inactivity_timeout is the elapsed time from the time //
// a read or a write was scheduled during which the //
diff --git a/iocore/net/SSLConfig.cc b/iocore/net/SSLConfig.cc
index ca61712..aa82eb0 100644
--- a/iocore/net/SSLConfig.cc
+++ b/iocore/net/SSLConfig.cc
@@ -514,7 +514,7 @@ SSLCertificateConfig::reconfigure()
// twice the healthcheck period to simulate a loading a large certificate
set.
if (is_action_tag_set("test.multicert.delay")) {
const int secs = 60;
- Debug("ssl", "delaying certificate reload by %dsecs", secs);
+ Debug("ssl", "delaying certificate reload by %d secs", secs);
ink_hrtime_sleep(HRTIME_SECONDS(secs));
}
diff --git a/iocore/net/SSLNetVConnection.cc b/iocore/net/SSLNetVConnection.cc
index 070e414..e4c9fbf 100644
--- a/iocore/net/SSLNetVConnection.cc
+++ b/iocore/net/SSLNetVConnection.cc
@@ -371,7 +371,7 @@ SSLNetVConnection::read_raw_data()
// If we have already moved some bytes successfully, adjust total_read to
reflect reality
// If any read succeeded, we should return success
if (r != rattempted) {
- // If the first read failds, we should return error
+ // If the first read fails, we should return error
if (r <= 0 && total_read > rattempted) {
r = total_read - rattempted;
} else {
@@ -408,7 +408,7 @@ SSLNetVConnection::read_raw_data()
} else {
Debug("proxyprotocol",
"[SSLNetVConnection::read_raw_data] proxy protocol DOES NOT have a
configured whitelist of trusted IPs but "
- "proxy protocol is ernabled on this port - processing all
connections");
+ "proxy protocol is enabled on this port - processing all
connections");
}
if (ssl_has_proxy_v1(this, buffer, &r)) {
@@ -1215,7 +1215,7 @@ SSLNetVConnection::sslServerHandShakeEvent(int &err)
// Clean up the epoll entry for signalling
SSL_clear_mode(ssl, SSL_MODE_ASYNC);
this->ep.stop();
- // Rectivate the socket, ready to rock
+ // Reactivate the socket, ready to rock
PollDescriptor *pd = get_PollDescriptor(this_ethread());
this->ep.start(
pd, this,
@@ -1550,7 +1550,7 @@ SSLNetVConnection::reenable(NetHandler *nh, int event)
// Reenabling from the handshake callback
//
- // Originally, we would wait for the callback to go again to execute
additinonal
+ // Originally, we would wait for the callback to go again to execute
additional
// hooks, but since the callbacks are associated with the context and the
context
// can be replaced by the plugin, it didn't seem reasonable to assume that
the
// callback would be executed again. So we walk through the rest of the
hooks
diff --git a/iocore/net/SSLNextProtocolSet.cc b/iocore/net/SSLNextProtocolSet.cc
index 2adefce..04c6330 100644
--- a/iocore/net/SSLNextProtocolSet.cc
+++ b/iocore/net/SSLNextProtocolSet.cc
@@ -29,7 +29,7 @@
// For currently defined protocol strings, see
// http://technotes.googlecode.com/git/nextprotoneg.html. The OpenSSL
// documentation tells us to return a string in "wire format". The
-// draft NPN RFC helpfuly refuses to document the wire format. The
+// draft NPN RFC helpfully refuses to document the wire format. The
// above link says we need to send length-prefixed strings, but does
// not say how many bytes the length is. For the record, it's 1.
@@ -78,7 +78,7 @@ fail:
return false;
}
-// copies th eprotocols but not the endpoints
+// copies the protocols but not the endpoints
SSLNextProtocolSet *
SSLNextProtocolSet::clone() const
diff --git a/iocore/net/SSLSessionTicket.cc b/iocore/net/SSLSessionTicket.cc
index 07eea13..9346b29 100644
--- a/iocore/net/SSLSessionTicket.cc
+++ b/iocore/net/SSLSessionTicket.cc
@@ -31,7 +31,7 @@
#include "SSLStats.h"
#include "P_SSLConfig.h"
-// Remvoe this when drop OpenSSL 1.0.2 support
+// Remove this when drop OpenSSL 1.0.2 support
#ifndef evp_md_func
#ifdef OPENSSL_NO_SHA256
#define evp_md_func EVP_sha1()
diff --git a/iocore/net/SSLUtils.cc b/iocore/net/SSLUtils.cc
index d2e2e97..1e390fd 100644
--- a/iocore/net/SSLUtils.cc
+++ b/iocore/net/SSLUtils.cc
@@ -382,7 +382,7 @@ ssl_client_hello_callback(SSL *s, int *al, void *arg)
const char *servername = nullptr;
const unsigned char *p;
size_t remaining, len;
- // Parse the servrer name if the get extension call succeeds and there are
more than 2 bytes to parse
+ // Parse the server name if the get extension call succeeds and there are
more than 2 bytes to parse
if (SSL_client_hello_get0_ext(s, TLSEXT_TYPE_server_name, &p, &remaining) &&
remaining > 2) {
// Parse to get to the name, originally from test/handshake_helper.c in
openssl tree
/* Extract the length of the supplied list of names. */
@@ -979,7 +979,7 @@ SSLMultiCertConfigLoader::check_server_cert_now(X509 *cert,
const char *certname
timeCmpValue = X509_cmp_current_time(X509_get_notBefore(cert));
if (timeCmpValue == 0) {
- // an error occured parsing the time, which we'll call a bogosity
+ // an error occurred parsing the time, which we'll call a bogosity
Error("invalid certificate %s: unable to parse notBefore time", certname);
return -3;
} else if (timeCmpValue > 0) {
@@ -990,7 +990,7 @@ SSLMultiCertConfigLoader::check_server_cert_now(X509 *cert,
const char *certname
timeCmpValue = X509_cmp_current_time(X509_get_notAfter(cert));
if (timeCmpValue == 0) {
- // an error occured parsing the time, which we'll call a bogosity
+ // an error occurred parsing the time, which we'll call a bogosity
Error("invalid certificate %s: unable to parse notAfter time", certname);
return -3;
} else if (timeCmpValue < 0) {
@@ -1762,7 +1762,7 @@ SSLConnect(SSL *ssl)
}
/**
- Load certificats to SSL_CTX
+ Load certificates to SSL_CTX
@static
*/
bool
diff --git a/iocore/net/Socks.cc b/iocore/net/Socks.cc
index a1a5999..ab1044f 100644
--- a/iocore/net/Socks.cc
+++ b/iocore/net/Socks.cc
@@ -480,7 +480,7 @@ loadSocksConfiguration(socks_conf_struct *socks_conf_stuff)
socks_conf_stuff->server_connect_timeout =
REC_ConfigReadInteger("proxy.config.socks.server_connect_timeout");
socks_conf_stuff->socks_timeout =
REC_ConfigReadInteger("proxy.config.socks.socks_timeout");
- Debug("Socks", "server connect timeout: %d socks respnonse timeout %d",
socks_conf_stuff->server_connect_timeout,
+ Debug("Socks", "server connect timeout: %d socks response timeout %d",
socks_conf_stuff->server_connect_timeout,
socks_conf_stuff->socks_timeout);
socks_conf_stuff->per_server_connection_attempts =
REC_ConfigReadInteger("proxy.config.socks.per_server_connection_attempts");
@@ -636,7 +636,7 @@ socks5BasicAuthHandler(int event, unsigned char *p, void
(**h_ptr)(void))
break;
case 0xff:
- Debug("Socks", "None of the Socks authentcations is acceptable "
+ Debug("Socks", "None of the Socks authentications is acceptable "
"to the server");
*h_ptr = nullptr;
ret = -1;
@@ -655,7 +655,7 @@ socks5BasicAuthHandler(int event, unsigned char *p, void
(**h_ptr)(void))
break;
default:
- // This should be inpossible
+ // This should be impossible
ink_assert(!"bad case value");
ret = -1;
break;
diff --git a/iocore/net/UnixNet.cc b/iocore/net/UnixNet.cc
index 76a10a4..63721b9 100644
--- a/iocore/net/UnixNet.cc
+++ b/iocore/net/UnixNet.cc
@@ -152,7 +152,7 @@ PollCont::do_poll(ink_hrtime timeout)
poll_timeout = net_config_poll_timeout;
}
}
-// wait for fd's to tigger, or don't wait if timeout is 0
+// wait for fd's to trigger, or don't wait if timeout is 0
#if TS_USE_EPOLL
pollDescriptor->result =
epoll_wait(pollDescriptor->epoll_fd,
pollDescriptor->ePoll_Triggered_Events, POLL_DESCRIPTOR_SIZE, poll_timeout);
diff --git a/iocore/net/UnixNetVConnection.cc b/iocore/net/UnixNetVConnection.cc
index 456fa95..5ecc216 100644
--- a/iocore/net/UnixNetVConnection.cc
+++ b/iocore/net/UnixNetVConnection.cc
@@ -1377,7 +1377,7 @@ UnixNetVConnection::migrateToCurrentThread(Continuation
*cont, EThread *t)
// Try to get the mutex lock for NetHandler of this NetVC
MUTEX_TRY_LOCK(lock_src, this->nh->mutex, t);
if (lock_src.is_locked()) {
- // Deattach this NetVC from original NetHandler & InactivityCop.
+ // Detach this NetVC from original NetHandler & InactivityCop.
this->nh->stopCop(this);
this->nh->stopIO(this);
// Put this NetVC into current NetHandler & InactivityCop.
diff --git a/iocore/net/YamlSNIConfig.cc b/iocore/net/YamlSNIConfig.cc
index 6ba226e..8fbb4d8 100644
--- a/iocore/net/YamlSNIConfig.cc
+++ b/iocore/net/YamlSNIConfig.cc
@@ -147,7 +147,7 @@ template <> struct convert<YamlSNIConfig::Item> {
}
// remove before 9.0.0 release
- // backwards compatibiity
+ // backwards compatibility
if (node[TS_verify_origin_server]) {
auto value =
node[TS_verify_origin_server].as<std::string>();
YamlSNIConfig::Level level =
static_cast<YamlSNIConfig::Level>(LEVEL_DESCRIPTOR.get(value));
diff --git a/iocore/net/test_P_Net.cc b/iocore/net/test_P_Net.cc
index f56dd19..185b158 100644
--- a/iocore/net/test_P_Net.cc
+++ b/iocore/net/test_P_Net.cc
@@ -55,7 +55,7 @@ struct NetTesterSM : public Continuation {
fflush(stdout);
break;
case VC_EVENT_READ_COMPLETE:
- /* FALLSTHROUGH */
+ /* FALLTHROUGH */
case VC_EVENT_EOS:
r = reader->read_avail();
str = new char[r + 10];
diff --git a/iocore/net/test_certlookup.cc b/iocore/net/test_certlookup.cc
index 31913b6..96a8f36 100644
--- a/iocore/net/test_certlookup.cc
+++ b/iocore/net/test_certlookup.cc
@@ -168,7 +168,7 @@ load_hostnames_csv(const char *fname, SSLCertLookup &lookup)
SSLCertContext ctx_cc(ctx);
// The input should have 2 comma-separated fields; this is the format that
you get when
- // you download the top 1M sites from alexa.
+ // you download the top 1M sites from Alexa.
//
// For example:
// 1,google.com
diff --git a/iocore/utils/I_OneWayMultiTunnel.h
b/iocore/utils/I_OneWayMultiTunnel.h
index 9351851..c4973e6 100644
--- a/iocore/utils/I_OneWayMultiTunnel.h
+++ b/iocore/utils/I_OneWayMultiTunnel.h
@@ -36,7 +36,7 @@
#define ONE_WAY_MULTI_TUNNEL_LIMIT 4
/**
- A generic state machine that connects a source virtual conection to
+ A generic state machine that connects a source virtual connection to
multiple target virtual connections. A OneWayMultiTunnel is similar to
the OneWayTunnel module. However, instead of connection one source
to one target, it connects multiple virtual connections - a source
diff --git a/iocore/utils/I_OneWayTunnel.h b/iocore/utils/I_OneWayTunnel.h
index 8a83564..d74401a 100644
--- a/iocore/utils/I_OneWayTunnel.h
+++ b/iocore/utils/I_OneWayTunnel.h
@@ -45,7 +45,7 @@
typedef void (*Transform_fn)(MIOBufferAccessor &in_buf, MIOBufferAccessor
&out_buf);
/**
- A generic state machine that connects two virtual conections. A
+ A generic state machine that connects two virtual connections. A
OneWayTunnel is a module that connects two virtual connections, a source
vc and a target vc, and copies the data between source and target. Once
the tunnel is started using the init() call, it handles all the events
diff --git a/iocore/eventsystem/I_VConnection.h
b/iocore/eventsystem/I_VConnection.h
index bc72ba5..193c62b 100644
--- a/iocore/eventsystem/I_VConnection.h
+++ b/iocore/eventsystem/I_VConnection.h
@@ -54,7 +54,7 @@ static constexpr int TS_VCONN_MAX_USER_ARG = 4;
#define VC_EVENT_READ_READY VC_EVENT_EVENTS_START
/**
- Any data in the accociated buffer *will be written* when the
+ Any data in the associated buffer *will be written* when the
Continuation returns.
*/
@@ -73,7 +73,7 @@ static constexpr int TS_VCONN_MAX_USER_ARG = 4;
#define VC_EVENT_ERROR EVENT_ERROR
/**
- VC_EVENT_INACTIVITY_TIMEOUT indiates that the operation (read or write) has:
+ VC_EVENT_INACTIVITY_TIMEOUT indicates that the operation (read or write) has:
-# been enabled for more than the inactivity timeout period
(for a read, there has been space in the buffer)
(for a write, there has been data in the buffer)
@@ -85,7 +85,7 @@ static constexpr int TS_VCONN_MAX_USER_ARG = 4;
#define VC_EVENT_INACTIVITY_TIMEOUT (VC_EVENT_EVENTS_START + 5)
/**
- Total time for some operation has been exeeded, regardless of any
+ Total time for some operation has been exceeded, regardless of any
intermediate progress.
*/
@@ -101,10 +101,10 @@ static constexpr int TS_VCONN_MAX_USER_ARG = 4;
// VC_EVENT_READ_READ occurs when data *has been written* into
// the associated buffer.
//
-// VC_EVENT_ERROR indicates that some error has occured. The
+// VC_EVENT_ERROR indicates that some error has occurred. The
// "data" will be either 0 if the errno is unavailable or errno.
//
// VC_EVENT_INTERVAL indidates that an interval timer has expired.
//
//
@@ -260,7 +260,7 @@ public:
must call this function to indicate that the VConnection can
be deallocated. After a close has been called, the VConnection
and underlying processor must not send any more events related
- to this VConnection to the state machine. Likeswise, the state
+ to this VConnection to the state machine. Likewise, the state
machine must not access the VConnection or any VIOs obtained
from it after calling this method.
@@ -335,7 +335,7 @@ public:
@param id Identifier associated to interpret the data field
@param data Value or pointer with state machine or VConnection data.
- @return True if the oparation is successful.
+ @return True if the operation is successful.
*/
virtual bool
@@ -356,7 +356,7 @@ public:
@param id Identifier associated to interpret the data field.
@param data Value or pointer with state machine or VConnection data.
- @return True if the oparation is successful.
+ @return True if the operation is successful.
*/
virtual bool
@@ -101,10 +101,10 @@ static constexpr int TS_VCONN_MAX_USER_ARG = 4;
// "data" will be either 0 if the errno is unavailable or errno.
//
-// VC_EVENT_INTERVAL indidates that an interval timer has expired.
+// VC_EVENT_INTERVAL indicates that an interval timer has expired.
//
//